# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/ndlong/bio/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/ndlong/bio/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Ndlong\\Bio\\": "packages/ndlong/bio/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Ndlong\Bio\Providers\BioServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Bio'  => Ndlong\Bio\Facades\Bio::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Ndlong\\BioTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Ndlong\Bio\Providers\BioServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Ndlong\Bio\Providers\BioServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Ndlong\Bio\Providers\BioServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/bio/{modulename}

**User**

    http://path-to-route-folder/user/bio/{modulename}

**Public**

    http://path-to-route-folder/bios


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/bio/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/bio/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/bio/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/bio/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/bio/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/bio/{modulename}/{slug}
    METHOD: GET